==> haskell-aeson-qq-0.8.3-204-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-qq
version:              0.8.3
visibility:           public
id:                   aeson-qq-0.8.3-5vWlCL1Ijbw9Vb2F3nXNKa
key:                  aeson-qq-0.8.3-5vWlCL1Ijbw9Vb2F3nXNKa
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  df6c1e50eeb97d5756613a2326843413
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.0.1/site-local/aeson-qq-0.8.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/aeson-qq-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/aeson-qq-0.8.3
hs-libraries:         HSaeson-qq-0.8.3-5vWlCL1Ijbw9Vb2F3nXNKa
depends:
    aeson-1.5.6.0-FdusChH0dokB9fXPeFrIPu
    attoparsec-0.14.1-2GQaG3RNGCb1FJmmtUw9yw base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    haskell-src-meta-0.8.7-DnwYSeIhLlr8qqKBoSAkwv parsec-3.1.14.0
    scientific-0.3.7.0-7fhwlmzNM9FCJeHDNMntaB template-haskell-2.17.0.0
    text-1.2.4.1 vector-0.12.3.0-wUfL5c2StS9dUQS7oblw1

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.3-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-qq
version:              0.8.3
visibility:           public
id:                   aeson-qq-0.8.3-JtJkUVfp2zOLvgpA6Er3iW
key:                  aeson-qq-0.8.3-JtJkUVfp2zOLvgpA6Er3iW
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  69ba6771d62a54947df24f7dfd15c1f2
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.0.1/site-local/aeson-qq-0.8.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/aeson-qq-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/aeson-qq-0.8.3
hs-libraries:         HSaeson-qq-0.8.3-JtJkUVfp2zOLvgpA6Er3iW
depends:
    aeson-1.5.6.0-5TyhNUN5QiGBKR8buVyIgL
    attoparsec-0.14.1-9kuPfEBVMov8pU89fXOVL9 base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    haskell-src-meta-0.8.7-IrO3mNTEI3IL1CLZff7xdI parsec-3.1.14.0
    scientific-0.3.7.0-85gPhyHadbV4QYqa7IGCyM template-haskell-2.17.0.0
    text-1.2.4.1 vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
